# HyperBKRGA

## Setting up the Environment 

To run any code in this repository, it is necessary to follow these steps:

- Create and activate a virtual environment:

```bash
$ python -m venv venv
$ venv/Scripts/activate
```

- Install the dependencies contained in `requirements.txt`
```bash
pip install -r requirements.txt
```

## Basic Example
With the environment set up, it is possible to run the simplest example as follows:

```bash
$ py ./src/examples/basic-example.py
```

## Experiments
To reproduce the experiments carried out in this work, run the `src/main.py` file.
Note that it is a time-consuming program.
